"""Pylons environment configuration"""
import os

from pylons import config

import pycrud.lib.app_globals as app_globals
import pycrud.lib.helpers
from pycrud.config.routing import make_map
from sqlalchemy import engine_from_config


def load_environment(global_conf, app_conf):
    """Configure the Pylons environment via the ``pylons.config``
    object
    """
    # Pylons paths
    root = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
    paths = dict(root=root,
                 controllers=os.path.join(root, 'controllers'),
                 static_files=os.path.join(root, 'public'),
                 templates=[os.path.join(root, 'templates')]
             )

    # Initialize config with the basic options
    config.init_app(global_conf, app_conf, package='pycrud',
                    template_engine='mako', paths=paths)

    config['routes.map'] = make_map()
    config['pylons.g'] = app_globals.Globals()
    config['pylons.h'] = pycrud.lib.helpers

    # Customize templating options via this variable
    tmpl_options = config['buffet.template_options']

    # CONFIGURATION OPTIONS HERE (note: all config options will override
    # any Pylons config options)
    config['pylons.g'].sa_engine = engine_from_config(config, 'sqlalchemy.default.')
    config['pylons.g'].base_url = config['base_url'].rstrip('/')
    config['pylons.g'].debug = config['debug']
    config['pylons.g'].custom_config = config['custom_config']

